==> TRONCO_2.6.1.zip: TRONCO/NEWS.Rd <==
\name{NEWS}
\title{News for the package \pkg{TRONCO}}
\encoding{UTF-8}

\section{Changes in Version 2.4.3}{
    \itemize{
        \item New algorithms: Edmonds, Gabow, Chow-Liu and Prim.
        \item New scores: PMI, CPMI, MI
        \item A better bootstrap implementation
    }
}

\section{Changes in Version 2.4.2}{
    \itemize{
        \item Implementation of maximum spanning tree algorithms.
        \item Implementation of a noise model for cumulative phenomena.
    }
}

\section{Changes in Version 2.4.1}{
    \itemize{
        \item A better implementation of remove.cycles.
    }
}

\section{Changes in Version 2.4.0}{
    \itemize{
        \item New statistics available for model confidence via
        cross-validation routines. New algorithms based on Minimum
        Spanning Tree extraction.
    }
}

\section{Changes in Version 2.0.0}{
    \itemize{
        \item Released in summer 2015 on our GitHUB, will replace the 
        Bioconductor version in autumn 2015. This version is parallel,
        includes also the CAPRI algorithm, supports common input formats
        such as GISTIC (for Copy Number Variants), MAF (for mutations' annotation),
        supports TCGA samples editing and queries to the CBio portal.
        This version comes with new plotting capabilities, and a general
        from-scratch design. It is not compatible with previous releases.
    }
}

\section{Changes in Version 1.0.0}{
    \itemize{
        \item Released in mid 2014 includes CAPRESE algorithm.
        It is now outdated and no more maintained. 
    }
}

==> TRONCO_2.8.2.zip: TRONCO/NEWS.Rd <==
\name{NEWS}
\title{News for the package \pkg{TRONCO}}
\encoding{UTF-8}

\section{Changes in Version 2.8.1}{
    \itemize{
        \item Minor fix on documentation
    }
}

\section{Changes in Version 2.7.7}{
    \itemize{
        \item RNA Seq validation
        \item Random restart on Hill Climbing added to CAPRI algorithm
        \item Minor fixes to algorithms and error model
    }
}

\section{Changes in Version 2.7.3}{
    \itemize{
        \item Assignment to .GlobalEnv removed
    }
}

\section{Changes in Version 2.6.1}{
    \itemize{
        \item Last stable releade with bugfix
    }
}

\section{Changes in Version 2.4.3}{
    \itemize{
        \item New algorithms: Edmonds, Gabow, Chow-Liu and Prim.
        \item New scores: PMI, CPMI, MI
        \item A better bootstrap implementation
    }
}

\section{Changes in Version 2.4.2}{
    \itemize{
        \item Implementation of maximum spanning tree algorithms.
        \item Implementation of a noise model for cumulative phenomena.
    }
}

\section{Changes in Version 2.4.1}{
    \itemize{
        \item A better implementation of remove.cycles.
    }
}

\section{Changes in Version 2.4.0}{
    \itemize{
        \item New statistics available for model confidence via
        cross-validation routines. New algorithms based on Minimum
        Spanning Tree extraction.
    }
}

\section{Changes in Version 2.0.0}{
    \itemize{
        \item Released in summer 2015 on our GitHUB, will replace the 
        Bioconductor version in autumn 2015. This version is parallel,
        includes also the CAPRI algorithm, supports common input formats
        such as GISTIC (for Copy Number Variants), MAF (for mutations' annotation),
        supports TCGA samples editing and queries to the CBio portal.
        This version comes with new plotting capabilities, and a general
        from-scratch design. It is not compatible with previous releases.
    }
}

\section{Changes in Version 1.0.0}{
    \itemize{
        \item Released in mid 2014 includes CAPRESE algorithm.
        It is now outdated and no more maintained. 
    }
}
